@@ -4,6 +4,15 @@
 
 #include "abacus.local.h"
 
+/*
+ *
+ */
+vector<Element>
+Matrix::remove(const int flag) {
+  MatrixBuffer* p = (MatrixBuffer*)buffer;
+  return p->elements(flag, true);
+}
+  
 /*
  *
  */
